# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["AccountsType"]

AccountsType: TypeAlias = Literal["external_accounts", "internal_accounts"]
